import IRESTClient from "./IRESTClient";
import ClientResponse from "./ClientResponse";
/**
 * @author Brett P
 * @author Tyler Scott
 */
export default class DefaultRESTClient implements IRESTClient {
    host: string;
    body: string;
    headers: {
        [key: string]: string;
    };
    method: string;
    parameters: {
        [key: string]: string;
    };
    uri: string;
    constructor(host: string);
    /**
     * Sets the authorization header using a key
     *
     * @param {string} key The value of the authorization header.
     * @returns {DefaultRESTClient}
     */
    withAuthorization(key: any): DefaultRESTClient;
    /**
     * Adds a segment to the request uri
     */
    withUriSegment(segment: any): DefaultRESTClient;
    /**
     * Get the full url + parameter list
     */
    getFullUrl(): string;
    /**
     * Adds a header to the request.
     *
     * @param key The name of the header.
     * @param value The value of the header.
     */
    withHeader(key: string, value: string): DefaultRESTClient;
    /**
     * Sets the body of the client request.
     *
     * @param body The object to be written to the request body as JSON.
     */
    withJSONBody(body: object): DefaultRESTClient;
    /**
     * Sets the http method for the request
     */
    withMethod(method: any): DefaultRESTClient;
    /**
     * Sets the uri of the request
     */
    withUri(uri: any): DefaultRESTClient;
    /**
     * Adds parameters to the request.
     *
     * @param name The name of the parameter.
     * @param value The value of the parameter, may be a string, object or number.
     */
    withParameter(name: any, value: any): DefaultRESTClient;
    /**
     * Run the request and return a promise. This promise will resolve if the request is successful
     * and reject otherwise.
     */
    go<T>(): Promise<ClientResponse<T>>;
    private getQueryString;
}
